# Alchina /al.ki.na/

[![Build Status](https://travis-ci.org/matthieugouel/alchina.svg?branch=master)](https://travis-ci.org/matthieugouel/alchina)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/alchina)
[![Coverage Status](https://coveralls.io/repos/github/matthieugouel/alchina/badge.svg?branch=master)](https://coveralls.io/github/matthieugouel/alchina?branch=master)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![license](https://img.shields.io/github/license/matthieugouel/alchina.svg)](https://github.com/matthieugouel/alchina/blob/master/LICENSE)

Alchina is a Machine Learning framework.

## Capabilities

**Regressors**

- Linear regressor
- Ridge regressor

**Classifiers**

- Linear classifier
- Ridge classifier

**Clusters**

- K-Means clustering

**Optimizers**

- Gradient descent
- Stochastic gradient descent
- Mini-batch gradient descent

**Preprocessors**

- Min-max normalization
- Standardization
- PCA

**Metrics**

- R2 score
- Confusion matrix
- Accuracy score
- Precision score
- Recall score
- F-Beta score
- F-1 score

**Model selection**

- Split dataset
